pitchtools.is_alphabetic_accidental_abbreviation
================================================

.. autofunction:: abjad.tools.pitchtools.is_alphabetic_accidental_abbreviation.is_alphabetic_accidental_abbreviation
